--- mga.c-orig	2008-08-02 17:50:24.000000000 +0200
+++ mga.c	2008-08-02 18:00:36.000000000 +0200
@@ -70,12 +70,14 @@
 #ifndef __LINUX_MGAVID_H
 #   define __LINUX_MGAVID_H
 
-#   define MGA_VID_CONFIG _IOR('J', 1, mga_vid_config_t)
-#   define MGA_VID_ON     _IO ('J', 2)
-#   define MGA_VID_OFF    _IO ('J', 3)
-#   define MGA_VID_FSEL   _IOR('J', 4, int)
+#   define MGA_VID_GET_VERSION  _IOR ('J', 1, uint32_t)
+#   define MGA_VID_CONFIG       _IOWR('J', 2, mga_vid_config_t)
+#   define MGA_VID_ON           _IO  ('J', 3)
+#   define MGA_VID_OFF          _IO  ('J', 4)
+#   define MGA_VID_FSEL         _IOW ('J', 5, uint32_t)
 #   define MGA_G200 0x1234
 #   define MGA_G400 0x5678
+#   define MGA_G550 0xDEF0
 
 #   define MGA_VID_FORMAT_YV12 0x32315659
 #   define MGA_VID_FORMAT_IYUV (('I'<<24)|('Y'<<16)|('U'<<8)|'V')
@@ -83,7 +85,7 @@
 #   define MGA_VID_FORMAT_YUY2 (('Y'<<24)|('U'<<16)|('Y'<<8)|'2')
 #   define MGA_VID_FORMAT_UYVY (('U'<<24)|('Y'<<16)|('V'<<8)|'Y')
 
-#   define MGA_VID_VERSION     0x0201
+#   define MGA_VID_VERSION     0x0202
 
 #   define MGA_NUM_FRAMES      1
 
@@ -105,6 +107,7 @@
     uint32_t format;
     uint32_t frame_size;
     uint32_t num_frames;
+    uint32_t capabilities;
 } mga_vid_config_t;
 #endif
 
@@ -163,6 +166,7 @@
 {
     int i_index;
     picture_t *p_pic;
+    uint32_t mga_version;
 
     I_OUTPUTPICTURES = 0;
 
@@ -191,6 +195,17 @@
     p_vout->output.i_chroma = VLC_FOURCC('Y','M','G','A');
     p_vout->p_sys->mga.format = MGA_VID_FORMAT_YV12;
 
+    if( ioctl(p_vout->p_sys->i_fd, MGA_VID_GET_VERSION, &mga_version) )
+    {
+        msg_Err( p_vout, "MGA get version ioctl failed" );
+        return -1;
+    }
+
+    if(mga_version != MGA_VID_VERSION)
+    {
+    	msg_Err(p_vout, "MGA missmatch between installed driver version and expected version");
+	return -1;
+    }
     if( ioctl(p_vout->p_sys->i_fd, MGA_VID_CONFIG, &p_vout->p_sys->mga) )
     {
         msg_Err( p_vout, "MGA config ioctl failed" );
